@@ -1,4 +1,4 @@
 # flake8: noqa
 from .version import __version__
 from .base import BaseSmartManager
-from .models import SmartManager
+from .models import SmartManager, SmartManagerMixin, SmartModelMixin
