@@ -12,26 +12,31 @@ class BaseSmartManager(object):
     def built_objs(self):
         return self._built_objs
 
-    def build_obj(self, model_class, updates=None, defaults=None, **kwargs):
+    def build_obj(self, model_class, is_deletable=True, updates=None, defaults=None, **kwargs):
         """
-        Builds an object using the upsert function in manager utils. All
-        built objects are added to the internal _built_objs list and returned.
+        Builds an object using the upsert function in manager utils. If the object can be deleted
+        by the smart manager, it is added to the internal _built_objs list and returned.
         """
         built_obj = upsert(model_class.objects, updates=updates, defaults=defaults, **kwargs)[0]
-        self._built_objs |= set([built_obj])
+        if is_deletable:
+            self._built_objs |= set([built_obj])
 
         return built_obj
 
-    def build_obj_using(self, smart_manager_class, template):
+    def build_using(self, smart_manager_class, template):
         """
         Builds objects using another builder and a template. Adds the resulting built objects
         from that builder to the built objects of this builder.
         """
         smart_manager = smart_manager_class(template)
-        built_obj = smart_manager.build()
+        built_objs = smart_manager.build()
         self._built_objs |= smart_manager.built_objs
 
-        return built_obj
+        # make sure build objs is a list or tuple
+        if type(built_objs) not in (list, tuple,):
+            built_objs = [built_objs]
+
+        return built_objs
 
     def build(self):
         """
